django_parser.py
================

`View code on Github <https://github.com/activist-org/ts-backend-check/blob/main/src/ts_backend_check/parsers/django_parser.py>`_

.. automodule:: ts_backend_check.parsers.django_parser
    :members:
    :private-members:
